@@ -14,14 +14,15 @@ GaussianLikelihood::~GaussianLikelihood()
 }
 
 
-double GaussianLikelihood::updateCoefficients(double& K1, double& K2, const double Observation, 
+double GaussianLikelihood::updateCoefficients(double& q, double& r, const double Observation, 
 											  const double ModelMean, const double ModelVariance) const
 {
-	// Lehel: Sec. 2.4
+    // Lehel: Sec. 2.4
 	double sigX2 = ModelVariance + likelihoodParameter;
 	double logLik;
-	K2 = - 1 / sigX2;
-	K1 = -K2 * (Observation - ModelMean);
-	logLik = -(log(2 * M_PI * sigX2) + (Observation - ModelMean) * K1) / 2;
+	r = - 1.0 / sigX2;
+	q = - r * (Observation - ModelMean);
+	
+	logLik = - 0.5 * ( log(2.0 * M_PI * sigX2) + (Observation - ModelMean) * q );
 	return logLik;
 }
